#
# spec file for package perl-Sereal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Sereal
Name:           perl-Sereal
Version:        5.004
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Binary serialization module for Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Sereal::Decoder) >= 5.004
BuildRequires:  perl(Sereal::Encoder) >= 5.004
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::LongString)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
Requires:       perl(Sereal::Decoder) >= 5.004
Requires:       perl(Sereal::Encoder) >= 5.004
%{perl_requires}

%description
_Sereal_ is an efficient, compact-output, binary and feature-rich
serialization protocol. The Perl encoder is implemented as the
Sereal::Encoder module, the Perl decoder correspondingly as
Sereal::Decoder. They are distributed separately to allow for safe
upgrading without downtime. (Hint: Upgrade the decoder everywhere first,
then the encoder.)

This 'Sereal' module is a very thin wrapper around both 'Sereal::Encoder'
and 'Sereal::Decoder'. It depends on both and loads both. So if you have a
user of both encoder and decoder, it is enough to depend on a particular
version of 'Sereal' and you'll get the most recent released versions of
'Sereal::Encoder' and 'Sereal::Decoder' whose version is smaller than or
equal to the version of 'Sereal' you depend on.

The protocol specification and many other bits of documentation can be
found in the github repository. Right now, the specification is at
https://github.com/Sereal/Sereal/blob/master/sereal_spec.pod, there is a
discussion of the design objectives in
https://github.com/Sereal/Sereal/blob/master/README.pod, and the output of
our benchmarks can be seen at
https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Thu Apr 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.004
  see /usr/share/doc/packages/perl-Sereal/Changes
  5.004
  * Decoder fixes: Fix thaw ordering for frozen objects. Nested THAW
    operations now happen in the documented LIFO order. Thanks to Marco
    Fontani for the report.
* Thu Feb  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 5.003
  see /usr/share/doc/packages/perl-Sereal/Changes
* Sun Sep  4 2022 Tina Müller <timueller+perl@suse.de>
- updated to 5.001
  see /usr/share/doc/packages/perl-Sereal/Changes
* Fri Jul 29 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.025
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.025 Thr Jul 28, 2022
  * Release with build fixes for the Decoder under threaded
    perls and MANIFEST update.
  4.024 Wed Jul 27, 2022
  * Changes to the FREEZE/THAW mechanism. Remove the part that
    says that FREEZE cannot return a list. It can, and we have
    supported it for a very long time, although I have not checked
    how far back this support goes. If you use the FREEZE/THAW
    API's you should upgrade to this version or later.
  * Test fixes for t/020_sort_keys.t hanging on some perls
    which do not come bundled with Hash::Util.
* Mon Feb 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 4.023
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.023 Sun Feb 20, 2022
  * Make it possible to upgrade with passing tests when using
    Sereal::Decoder 4.015 - 4.019 on threaded debugging perls.
    IF YOU USE THREADED PERLS YOU ARE STRONGLY ADVISED TO UPDATE
    TO THIS VERSION OR LATER. *UPGRADE THE DECODER IMMEDIATELY*.
  4.022 Sat Feb 19, 2022
  4.021 Fri Feb 18, 2022
  * Early but incomplete versions of 4.023, skip these releases.
  4.020 Thurs Feb 17, 2022
  * Fix "panic: free from wrong pool" errors on threaded builds.
    This error is only visible on DEBUGGING perls however it exists
    regardless. If you are using a threaded build upgrade to this!
    Thanks to Andreas J. Koenig for finding the bug, and Nicholas Clark
    for suggesting valgrind to debug and fix it.
  4.019 Mon Feb 7, 2022
  * Fix build issue with latest perl - Thanks to Nicholas Clark
  * Update zstd to 1.5.1
* Tue Aug  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.018
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.018 Thurs Aug 3, 2020
  * Fix issue with gcc 10 with snappy compression.
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.017
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.017 Thurs July 9, 2020
  * The build fixes in 4.016 didn't work correctly, this should fix them.
  4.016 Thurs July 9, 2020
  * Fix some dependency issues in build process
  4.015 Weds  July 8, 2020
  * Build fixes (missing dependency)
  * Hardening against corrupted data
  * New thresholds to manage decoding process
  4.014 Thurs June 11, 2020
  * Fix build issue on non-win32 platforms.
  * Update zstd to 1.4.5
  4.012 Tues February 4, 2020
  * Fix memory leak in looks_like_sereal(), thanks to Kirill Sysoev
* Wed Feb  5 2020 <timueller+perl@suse.de>
- updated to 4.011
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.011 Tues February 4, 2020
  * Fix and test custom opcode logic for 5.31.2 and later.
  4.010 Tues February 4, 2020
  * Encoder/Decoder: Update miniz
  * Encoder/Decoder: Update zstd
  * Sereal/Encoder/Decoder: perltidy perl code to a standard style
* Sat Feb  1 2020 <timueller+perl@suse.de>
- updated to 4.009
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.009 Fri January 31, 2020
  * Encoder/Decoder: Update ppport.h for modern perls.
  4.008 Thurs Jan 30, 2020
  * Encoder/Decoder: Build fixes for modern perls.
  * Encoder/Decoder: Pod fixes
* Wed Apr 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.007
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.007 Tues Apr 9, 2019
  * Sereal: restore write_sereal(), read_sereal() as aliases to write_sereal_file()
    and read_sereal_file(). Better tests for exported subs. Add SRL_UNCOMPRESSED,
    SRL_SNAPPY, SRL_ZLIB, SRL_ZSTD exports.
  * Decoder: tweak docs for looks_like_sereal/scalar_looks_like_sereal
  4.006 Mon Apr 8, 2019
  * Sereal: fix read_sereal_file(),
* Tue Apr  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.006
  see /usr/share/doc/packages/perl-Sereal/Changes
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of summary.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 4.005
  see /usr/share/doc/packages/perl-Sereal/Changes
* Sun Sep  4 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal/Changes
* Fri Sep  2 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal/Changes
  3.015 Thu Sep  1 20:18:44 CEST 2016
  * Fix builds under 5.25+
  * Fix various buffer overun bugs found using AFL (thanks to dgryski)
  * Fix issue in decode_from_file()
* Thu Dec 10 2015 coolo@suse.com
- updated to 3.014
  see /usr/share/doc/packages/perl-Sereal/Changes
* Mon Nov 16 2015 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Sereal/Changes
  3.006 Nov 14 2015
  * [DECODER] fix segfaults from heavily corrupted data. Guards
    against various pathological cases which could cause segfaults
    fixed. Thanks to Damian Gryski and "fuzzing sereal with afl"
    for finding these cases.
  * [ENCODER] Various subtle fixes to how we choose whether to serialize
    the string or numeric version of a value, in particular to
    ensure that "00" always round trips as "00", and related issues.
    Note this fix has correctness and performance consequences. In
    some cases values that used to serialized as integers (arguably
    incorrectly) will be serialized as strings instead, and some code
    maybe be slower to serialize.
    NOTE: Some issues related to this subject are not fixable without
    a protocol change. In particular this change may affect the behavior
    of code that uses binary logical operators on values serialized
    with Perl.
    Thanks to Zefram, Tom, and others for help with this issue.
  * Fixups for cast warnings under -Wint-to-ptr builds by using
    using PTR2INT and INT2PTR for casting our objects.
  * Win32 fixes
  * Build improvements
  * Changes to how we generate constants
* Sat May  9 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
